@@ -5,6 +5,8 @@
 ## - univention-ad-connector
 ## bugs:
 ##  - 55150
+## tags:
+##  - skip_admember
 
 import pytest
 from ldap.dn import dn2str, str2dn
@@ -97,7 +99,7 @@ def test_user_sync_from_ad_to_udm_with_ignorefilter(object_class, identifying_at
         if non_filtered_attr == identifying_attr:
             # if attr == id, we effectively move the object, not just modify it
             parent = str2dn(ad_dn)[1:]
-            new_dn = dn2str([[(non_filtered_attr, object_attrs[non_filtered_udm_attr].decode("utf-8"), 1)]] + parent)
+            new_dn = dn2str([[(non_filtered_attr, object_attrs[non_filtered_udm_attr].decode("utf-8"), 1)], *parent])
             ad_dn = ad.move(ad_dn, new_dn)
         else:
             ad.set_attributes(ad_dn, {non_filtered_attr: [object_attrs[non_filtered_udm_attr]]})
@@ -114,7 +116,7 @@ def test_user_sync_from_ad_to_udm_with_ignorefilter(object_class, identifying_at
             # if attr == id, we effectively move the object, not just modify it
             new_rdn = object_attrs[filtered_udm_attr].decode("utf-8")
             parent = str2dn(ad_dn)[1:]
-            new_dn = dn2str([[(filtered_attr, new_rdn, 1)]] + parent)
+            new_dn = dn2str([[(filtered_attr, new_rdn, 1)], *parent])
             ad_dn = ad.move(ad_dn, new_dn)
             # in this case, the UDM object wont sync as it is still matching the ignore filter. too bad...
             object_attrs[filtered_udm_attr] = filtered_attr_value
