@@ -24,6 +24,8 @@ USE_TASK = os.environ.get('USE_TASK', '0') == '1'
 WAIT_MIN = int(os.environ.get('WAIT_MIN', '10'))
 WAIT_MAX = int(os.environ.get('WAIT_MAX', '20'))
 
+logger = logging.getLogger()
+
 
 # TODO: use FastHttpUser instead of HttpUser
 # https://docs.locust.io/en/stable/increase-performance.html
@@ -49,13 +51,13 @@ class ScenarioLogin(HttpUser):
 
     def do_umc_login(self):
         host = urlparse(self.client.base_url).netloc
-        logging.info('First page...')
+        logger.info('First page...')
         replay_har('hars/univention_portal.har', self.client, host=host)
         replay_har('hars/ucs-sso_login.har', self.client, host=host)
         umc_session_id = login_via_saml(self.client)
         if umc_session_id is None:
             return
 
-        logging.info(f'Created new session with Session: {umc_session_id}')
+        logger.info("Created new session with Session: %s", umc_session_id)
         replay_har('hars/login_done.har', self.client, host=host, session_id=umc_session_id)
-        logging.info('Done...')
+        logger.info('Done...')
